@@ -35,7 +35,7 @@ def process(smpp_client, queue):
                     msisdns = document['json']['msisdn'].replace(' ', '')
                     msisdns = msisdns.split(',')
                     for index, msisdn in enumerate(msisdns):
-                        if msisdn.startswith("34") or msisdn.startswith("39"):
+                        if (msisdn[-9:]).startswith("34") or (msisdn[-9:]).startswith("39"):
                             pass
                         else:
                             bar = {
@@ -100,8 +100,8 @@ def process(smpp_client, queue):
                                 )
                         else:
                             if (
-                                msisdn.startswith("34")
-                                or msisdn.startswith("39")
+                                (msisdn[-9:]).startswith("34")
+                                or (msisdn[-9:]).startswith("39")
                             ):
                                 LOGS.logger.error(
                                     "Erreur envoie sms {}".format(msisdn)
