@@ -163,7 +163,7 @@ class Client(object):
                     "AND code=:err_code AND message_id=:message_id"
                     )
                 LOGS.logger.info(sql)
-                if msisdn_dest.startswith("34") or msisdn_dest.startswith("39"):
+                if (msisdn_dest[-9:]).startswith("34") or (msisdn_dest[-9:]).startswith("39"):
                     LOGS.logger.info("-----", msisdn_dest, "-----")
                     db.query(
                         sql,
@@ -175,7 +175,7 @@ class Client(object):
                         msisdn=msisdn_dest[-9:]
                         )
                 else:
-                    LOGS.logger.info("-----", msisdn_dest, ":", infos['stat'])
+                    LOGS.logger.info("-----{}: {}".format(msisdn_dest, infos['stat']))
                     db.query(
                         sql,
                         message_id=infos['id'][1:],
